@@ -22,10 +22,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # Edit these for every release:
 
-version = '1.3.32'  # Current version number of the application
+version = '1.3.33'  # Current version number of the application
 tskversion = 37  # Current version number of the task file format, changed to 37 for release 1.3.23.
-release_day = '28'  # Day number of the release, 1-31, as string
-release_month = 'August'  # Month of the release in plain English
+release_day = '13'  # Day number of the release, 1-31, as string
+release_month = 'October'  # Month of the release in plain English
 release_year = '2013'  # Year of the release as string
 release_status = 'stable'  # One of 'alpha', 'beta', 'stable'
 
