@@ -17,6 +17,4 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 '''
 
 import desktop
-import sys, os
-sys.path.append(os.path.dirname(__file__))
 import apscheduler.scheduler
